#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import logging

import ovirtsdk4 as sdk
import ovirtsdk4.types as types

logging.basicConfig(level=logging.DEBUG, filename='test.log')

# This example will connect to the server and print the names and identifiers of all the virtual machines:

# Create the connection to the server:
connection = sdk.Connection(
    url='https://hostname/ovirt-engine/api',
    username='admin@internal',
    password='redhat123',
    ca_file='ca.pem',
    debug=True,
    log=logging.getLogger(),
)

system_service = connection.system_service()
storage_domains_service = system_service.storage_domains_service()

storage_domain = storage_domains_service.list(search='name=nfs3')[0]

# Print the storage domain name and identifier
print("%s: %s" % (storage_domain.name, storage_domain.id))

storage_domain_service = storage_domains_service.storage_domain_service(storage_domain.id)

# Get the reference to the "vms" service:
vms_service = storage_domain_service.vms_service()

unregistered_vms = vms_service.list(query={ 'unregistered': 'true' })

# Print the virtual machine names and identifiers:
for vm in unregistered_vms:
    print("%s: %s" % (vm.name, vm.id))

# Close the connection to the server:
connection.close()
